library(tidyverse)
library(stevemisc)

# Be mindful of the path here. File name should be "Curtis 2012, 2015, 2018 UK Panel.dta".
# Also: we recommend (for tidying sake) to keep this file in a separate subdirectory called "data" within
#   your working environment.
Data <- haven::read_dta("data/Curtis 2012, 2015, 2018 UK Panel.dta")

# Here's how this script is going to work for the outputs. The script will spit stuff out into two directories.
# Tables will be saved as .html files and put into a directory called "tabs"
# Figures/plots will be saved as .png files and put into a directory called "plots".
# Within *both* of those, there will be a separate subdirectory (subsubsdirectory, if you will) for stuff that
#   is there for robustness checks. That directory will be named "robustness".


if (!dir.exists("tabs")){
  dir.create("tabs")
} else {
  print("directory already exists!")
}

if (!dir.exists("tabs/robustness")){
  dir.create("tabs/robustness")
} else {
  print("directory already exists!")
}


if (!dir.exists("plots")){
  dir.create("plots")
} else {
  print("directory already exists!")
}

if (!dir.exists("plots/robustness")){
  dir.create("plots/robustness")
} else {
  print("directory already exists!")
}


# Amber added a morenatthaneu variable and this new exclnatid in her script

Data %>%
  # quickie education fix
  mutate(educNEW = ifelse(year == 2018 & educNEW == 1, 0, educNEW),
         educNEW = ifelse(year == 2018 & educNEW == 2, 1, educNEW),
         educNEW = ifelse(year == 2018 & educNEW == 3, 2, educNEW),
         educNEW = ifelse(year == 2018 & educNEW == 4, 3, educNEW)) %>% 
  mutate(morenatthaneu = natid - europeanid,
         exclnatidd = ifelse((natid > europeanid) & (natid>regid), 1, 0),
         exclnatidi = ifelse(europeanid >= regid, natid - europeanid, natid-regid)) -> Data

Data %>%
  group_by(year) %>%
  summarize_at(vars("exclnatidd", "exclnatidi"), mean)

# Let's do min-max scaling for these variables
# "worried_britishvalsid", "hhincyr", "cultid"
Data %>% haven::zap_labels(.) %>%
  mutate_at(vars("openness5", "conscientiousness5", "extraversion5",
                 "agreeableness5", "emostability5","age",
                 "educNEW","occupprestige", "rururb",
                 "lrideol","countryben",
                 "polint","oli2","pmapprov",
                 "trustEUinsts"), list(`01` = ~scales::rescale(.))) %>%
  rename_at(vars(contains("_01")),
            ~gsub('_', '', .)) -> Data

Data %>%
  group_by(ID) %>%
  mutate_at(vars("europeanid", "natid", "regid", "morenatthaneu","exclnatidd","exclnatidi"),
            list(l1 = ~dplyr::lag(.,1))) %>%
  rename_at(vars(contains("_l1")),
            ~paste("l1", gsub("_l1", "", .), sep = "_") ) %>%
  ungroup() -> Data

Data %>%
  group_by(ID) %>%
  mutate_at(vars("europeanid", "natid", "regid", "morenatthaneu","exclnatidd","exclnatidi"),
            list(l2 = ~dplyr::lag(.,2))) %>%
  rename_at(vars(contains("_l2")),
            ~paste("l2", gsub("_l2", "", .), sep = "_") ) %>%
  ungroup() -> Data


Data %>%
  mutate_at(vars("l1_europeanid", "l1_natid", "l1_regid", "l1_morenatthaneu", "l1_exclnatidd", "l1_exclnatidi"),
            list(`01` = ~scales::rescale(.))) %>%
  rename_at(vars(contains("_01")),
            ~gsub('_01', '01', .)) -> Data

Data %>%
  mutate_at(vars("l2_europeanid", "l2_natid", "l2_regid", "l2_morenatthaneu",  "l2_exclnatidd", "l2_exclnatidi"),
            list(`01` = ~scales::rescale(.))) %>%
  rename_at(vars(contains("_01")),
            ~gsub('_01', '01', .)) -> Data

Data %>% select(ID, region, year, citizen, male, age, educNEW, occupprestige, rururb, 
                lrideol, countryben, polint, oli2, pmapprov,
                trustEUinsts, eth_white, rel_christian, 
                regid, europeanid, natid, morenatthaneu:ncol(.))  -> Sub

Sub %>% group_by(ID) %>%
  filter(!is.na(year)) %>%
  mutate(n = n_distinct(year)) %>%
  filter(n == 3) %>%
  ungroup() -> Balanced

# Let's get some histograms -----


Sub %>%
  group_by(year, regid) %>%
  tally() %>% na.omit %>% ungroup() %>%
  group_by(year) %>%
  mutate(total = sum(n),
         perc = n/total) %>%
  ungroup() %>%
  mutate(year = forcats::fct_inorder(as.factor(year))) %>%
  na.omit %>%
  ggplot(.,aes(as.factor(regid), perc, fill=year)) +
  theme_steve_web() +  scale_fill_brewer(palette = "OrRd") +
  geom_bar(stat="identity", position="dodge2", color="black") +
  scale_x_discrete(labels = c("Do Not Identify\nWith It At All", "2", "3",
                              "4", "5","6", "Identify Very Strongly\nWith It")) +
  scale_y_continuous(labels = scales::percent) +
  labs(x = "",
       y = "Percentage of Respondents",
       fill = "",
       title = "Identification with Region")

ggsave("plots/histogram-regid-ukgp.png")

Sub %>%
  group_by(year, natid) %>%
  tally() %>% na.omit %>% ungroup() %>%
  group_by(year) %>%
  mutate(total = sum(n),
         perc = n/total) %>%
  ungroup() %>%
  mutate(year = forcats::fct_inorder(as.factor(year))) %>%
  na.omit %>%
  ggplot(.,aes(as.factor(natid), perc, fill=year)) +
  theme_steve_web() +  scale_fill_brewer(palette = "OrRd") +
  geom_bar(stat="identity", position="dodge2", color="black") +
  scale_x_discrete(labels = c("Do Not Identify\nWith It At All", "2", "3",
                              "4", "5","6", "Identify Very Strongly\nWith It")) +
  scale_y_continuous(labels = scales::percent) +
  labs(x = "",
       y = "Percentage of Respondents",
       fill = "",
       title = "Identification with Nation")


ggsave("plots/histogram-natid-ukgp.png")

Sub %>%
  group_by(year, europeanid) %>%
  tally() %>% na.omit %>% ungroup() %>%
  group_by(year) %>%
  mutate(total = sum(n),
         perc = n/total) %>%
  ungroup() %>%
  mutate(year = forcats::fct_inorder(as.factor(year))) %>%
  na.omit %>%
  ggplot(.,aes(as.factor(europeanid), perc, fill=year)) +
  theme_steve_web() +  scale_fill_brewer(palette = "OrRd") +
  geom_bar(stat="identity", position="dodge2", color="black") +
  scale_x_discrete(labels = c("Do Not Identify\nWith It At All", "2", "3",
                              "4", "5","6", "Identify Very Strongly\nWith It")) +
  scale_y_continuous(labels = scales::percent) +
  labs(x = "",
       y = "Percentage of Respondents",
       fill = "",
       title = "Identification with Europe")

ggsave("plots/histogram-eurid-ukgp.png")


Sub %>%
  group_by(year, exclnatidi) %>%
  tally() %>% na.omit %>% ungroup() %>%
  group_by(year) %>%
  mutate(total = sum(n),
         perc = n/total) %>%
  ungroup() %>%
  mutate(year = forcats::fct_inorder(as.factor(year))) %>%
  na.omit %>%
  ggplot(.,aes(as.factor(exclnatidi), perc, fill=year)) +
  theme_steve_web() +  scale_fill_brewer(palette = "OrRd") +
  geom_bar(stat="identity", position="dodge2", color="black") +
  scale_x_discrete(labels = c("Exclusive\nRegional or European\nIdentification", "-5", "-4", "-3", "-2", "-1",
                              "National\nIdentification\nEqual to\nOther Identification", "1", "2", "3",
                              "4", "5", "Exclusive\nNational Identification")) +
  scale_y_continuous(labels = scales::percent) +
  labs(x = "",
       y = "Percentage of Respondents",
       fill = "",
       title = "Exclusive National Identification")

ggsave("plots/robustness/histogram-exclnatid-ukgp.png", width=11)



Sub %>%
  group_by(year, morenatthaneu) %>%
  tally() %>% na.omit %>% ungroup() %>%
  group_by(year) %>%
  mutate(total = sum(n),
         perc = n/total) %>%
  ungroup() %>%
  mutate(year = forcats::fct_inorder(as.factor(year))) %>%
  na.omit %>%
  ggplot(.,aes(as.factor(morenatthaneu), perc, fill=year)) +
  theme_steve_web() +  scale_fill_brewer(palette = "OrRd") +
  geom_bar(stat="identity", position="dodge2", color="black") +
  scale_x_discrete(labels = c("Exclusive\nEuropean\nIdentification", "-5", "-4", "-3", "-2", "-1",
                              "National\nIdentification\nEqual to\nEuropean Identification", "1", "2", "3",
                              "4", "5", "Exclusive\nNational\nIdentification")) +
  scale_y_continuous(labels = scales::percent) +
  labs(x = "",
       y = "Percentage of Respondents",
       fill = "",
       title = "Exclusive National Identification")

ggsave("plots/histogram-morenatthaneu-ukgp.png", width=11)


haven::write_dta(Balanced, "data/ukg-balanced-panel.dta")
haven::write_dta(Sub, "data/ukg-panel.dta")

# Dynamic panel model restricted to citizens ----
library(plm)

# Amber wants a particular layout of variables and it'd probably just be easier to do it this way.
base_reg <- as.formula("regid ~  openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + l1_regid01")

base_nat <- as.formula("natid ~  openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + l1_natid01")

base_eur <- as.formula("europeanid ~  openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + l1_europeanid01")

base_excl <- as.formula("exclnatidi ~  openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + l1_exclnatidi01")

base_excl_orig <- as.formula("morenatthaneu ~  openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + l1_morenatthaneu01")


full_reg <- as.formula("regid ~  openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + lrideol01 + oli201 + occupprestige01 + 
                       age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + l1_regid01")

full_nat <- as.formula("natid ~  openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + lrideol01 + oli201 + occupprestige01 + 
                       age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + l1_natid01")

full_eur <- as.formula("europeanid ~  openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + lrideol01 + oli201 + occupprestige01 + 
                       age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + l1_europeanid01")

full_excl <- as.formula("exclnatidi ~  openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + lrideol01 + oli201 + occupprestige01 + 
                        age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + l1_exclnatidi01")

full_excl_orig <- as.formula("morenatthaneu ~  openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + lrideol01 + oli201 + occupprestige01 + 
                        age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + l1_morenatthaneu01")

CSE <- function(mod) {
  mod %>%
    vcovHC() %>% 
    diag() %>% 
    sqrt() %>% 
    as.data.frame() %>% rownames_to_column() %>% as_tibble() %>%
    rename(std.error = 2) %>%
    select(-rowname) %>%
    bind_cols(broom::tidy(mod) %>% select(term, estimate), .) 
}

summary(M1 <- plm(base_reg,
                  data=subset(Sub, citizen==1), model="random", index=c("ID", "year")))

summary(M1wi <- plm(base_reg,
                  data=subset(Sub, citizen==1), model="within", index=c("ID", "year")))


# M1a <- lm(update(base_reg, paste("~ . +", "l2_regid01")), data=subset(Balanced))

summary(M2 <- plm(base_nat,
                  data=subset(Sub, citizen==1), model="random", index=c("ID", "year")))

summary(M2wi <- plm(base_nat,
                  data=subset(Sub, citizen==1), model="within", index=c("ID", "year")))

summary(M3 <- plm(base_eur,
                  data=subset(Sub, citizen==1), model="random", index=c("ID", "year")))

summary(M3wi <- plm(base_eur,
                  data=subset(Sub, citizen==1), model="within", index=c("ID", "year")))

summary(M4 <- plm(base_excl_orig,
                  data=subset(Sub, citizen==1), model="random", index=c("ID", "year")))


summary(M4wi <- plm(base_excl_orig,
                  data=subset(Sub, citizen==1), model="within", index=c("ID", "year")))





library(stargazer)

stargazer(M1, M2, M3, M4, type="html",
          covariate.labels = c("Openness", "Conscientiousness", "Extraversion",
                                "Agreeableness", "Emotional Stability",
                               "Age","Male","Education", "Urban", "White Ethnicity",
                               "Christian", "Lagged Regional ID", "Lagged National ID",
                               "Lagged European ID", "Lagged Exclusive National ID"),
          omit.stat = c("F", "Rsq"),
          title = "Baseline Results, UK Panel",
          notes = "Panel includes two waves (2015, 2018, with baseline lags from 2012) and 1,044 unique respondents",
          dep.var.labels = c("Regional ID", "National ID", "European ID", "Exclusive National ID"),
          out = "tabs/ukg-panel-baseline.html")


summary(M5 <- plm(full_reg,
                  data=subset(Sub, citizen==1), model="random", index=c("ID", "year")))


# M1a <- lm(update(base_reg, paste("~ . +", "l2_regid01")), data=subset(Balanced))

summary(M6 <- plm(full_nat,
                  data=subset(Sub, citizen==1), model="random", index=c("ID", "year")))

summary(M7 <- plm(full_eur,
                  data=subset(Sub, citizen==1), model="random", index=c("ID", "year")))

summary(M8 <- plm(full_excl_orig,
                  data=subset(Sub, citizen==1), model="random", index=c("ID", "year")))


stargazer(M5, M6, M7, M8, type="html",
          covariate.labels = c("Openness", "Conscientiousness", "Extraversion",
                               "Agreeableness", "Emotional Stability", "Ideology (L-R)",
                               "Opinion Leadership Index", "Occupational Prestige",
                               "Age","Male","Education", "Urban", "White Ethnicity",
                               "Christian", "Lagged Regional ID", "Lagged National ID",
                               "Lagged European ID", "Lagged Exclusive National ID"),
          omit.stat = c("F", "Rsq"),
          title = "Full Results, UK Panel",
          notes = "Panel includes two waves (2015, 2018, with baseline lags from 2012) and 924 unique respondents",
          dep.var.labels = c("Regional ID", "National ID", "European ID", "Exclusive National ID"),
          out = "tabs/ukg-panel-full.html")






Balanced %>% group_by(ID) %>%
  mutate_at(vars("openness501", "conscientiousness501","extraversion501",
                 "agreeableness501","emostability501"),
            list(l1 = ~dplyr::lag(., 1),
                 l2 = ~dplyr::lag(.,2))) %>%
  rename_at(vars(contains("_l1")),
            ~paste("l1", gsub("_l1", "", .), sep = "_") )  %>%
  rename_at(vars(contains("_l2")),
            ~paste("l2", gsub("_l2", "", .), sep = "_") ) -> Balanced


# Appendix: Let's do some robustness tests. -----
# * First: let's do the full on those that appear in all three waves.


summary(M10 <- plm(full_reg,
                  data=subset(Balanced, citizen==1), model="random", index=c("ID", "year")))

summary(M11 <- plm(full_nat,
                  data=subset(Balanced, citizen==1), model="random", index=c("ID", "year")))

summary(M12 <- plm(full_eur,
                  data=subset(Balanced, citizen==1), model="random", index=c("ID", "year")))

summary(M13 <- plm(full_excl_orig,
                  data=subset(Balanced, citizen==1), model="random", index=c("ID", "year")))


stargazer(M10, M11, M12, M13, type="html",
          covariate.labels = c("Openness", "Conscientiousness", "Extraversion",
                               "Agreeableness", "Emotional Stability", "Ideology (L-R)",
                               "Opinion Leadership Index", "Occupational Prestige",
                               "Age","Male","Education", "Urban", "White Ethnicity",
                               "Christian", "Lagged Regional ID", "Lagged National ID",
                               "Lagged European ID", "Lagged Exclusive National ID"),
          omit.stat = c("F", "Rsq"),
          title = "Full Results, Balanced UK Panel",
          notes = "Panel includes two waves (2015, 2018, with baseline lags from 2012) and 479 unique respondents",
          dep.var.labels = c("Regional ID", "National ID", "European ID", "Exclusive National ID"),
          out = "tabs/robustness/ukg-panel-full-balanced.html")

# * Double lags on the DV -----

summary(M14 <- lm(regid ~  openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + lrideol01 + oli201 + occupprestige01 + 
                    age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + l1_regid01 + l2_regid01,
                   data=subset(Balanced, citizen==1)))


summary(M15 <- lm(natid ~  openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + lrideol01 + oli201 + occupprestige01 + 
                    age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + l1_natid01 + l2_natid01,
                  data=subset(Balanced, citizen==1)))

summary(M16 <- lm(europeanid ~  openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + lrideol01 + oli201 + occupprestige01 + 
                    age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + l1_europeanid01 + l2_europeanid01,
                  data=subset(Balanced, citizen==1)))


summary(M17 <- lm(morenatthaneu ~  openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + lrideol01 + oli201 + occupprestige01 + 
                    age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + l1_morenatthaneu01 + l2_morenatthaneu01,
                  data=subset(Balanced, citizen==1)))


stargazer(M14, M15, M16, M17, type="html",
          covariate.labels = c("Openness", "Conscientiousness", "Extraversion",
                               "Agreeableness", "Emotional Stability", "Ideology (L-R)",
                               "Opinion Leadership Index", "Occupational Prestige",
                               "Age","Male","Education", "Urban", "White Ethnicity",
                               "Christian", "Lagged Regional ID (1)", "Lagged Regional ID (2)", 
                               "Lagged National ID (1)", "Lagged National ID (2)",
                               "Lagged European ID (1)", "Lagged European ID (2)",
                               "Lagged Exclusive National ID (1)", "Lagged Exclusive National ID (2)"),
          omit.stat = c("F", "Rsq", "ser"),
          title = "Full Results, Balanced UK Panel (2018, with Double DV Lags)",
          dep.var.labels = c("Regional ID", "National ID", "European ID", "Exclusive National ID"),
          out = "tabs/robustness/ukg-panel-full-balanced-double-dv-lags.html")


# * Double lags on everything -----


summary(M18 <- lm(regid ~  openness501 + l1_openness501 + l2_openness501 +
                    conscientiousness501 + l1_conscientiousness501 + l2_conscientiousness501 + 
                    extraversion501 + l1_extraversion501 + l2_extraversion501 +
                    agreeableness501 + l1_agreeableness501 + l2_agreeableness501 +
                    emostability501 + l1_emostability501 + l2_emostability501 +
                    lrideol01 + oli201 + occupprestige01 + 
                    age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + l1_regid01 + l2_regid01,
                  data=subset(Balanced, citizen==1)))


summary(M19 <- lm(natid ~  openness501 + l1_openness501 + l2_openness501 +
                    conscientiousness501 + l1_conscientiousness501 + l2_conscientiousness501 + 
                    extraversion501 + l1_extraversion501 + l2_extraversion501 +
                    agreeableness501 + l1_agreeableness501 + l2_agreeableness501 +
                    emostability501 + l1_emostability501 + l2_emostability501 +
                    lrideol01 + oli201 + occupprestige01 + 
                    age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + l1_natid01 + l2_natid01,
                  data=subset(Balanced, citizen==1)))

summary(M20 <- lm(europeanid ~  openness501 + l1_openness501 + l2_openness501 +
                    conscientiousness501 + l1_conscientiousness501 + l2_conscientiousness501 + 
                    extraversion501 + l1_extraversion501 + l2_extraversion501 +
                    agreeableness501 + l1_agreeableness501 + l2_agreeableness501 +
                    emostability501 + l1_emostability501 + l2_emostability501 +
                    lrideol01 + oli201 + occupprestige01 + 
                    age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + l1_europeanid01 + l2_europeanid01,
                  data=subset(Balanced, citizen==1)))


summary(M21 <- lm(morenatthaneu ~  openness501 + l1_openness501 + l2_openness501 +
                    conscientiousness501 + l1_conscientiousness501 + l2_conscientiousness501 + 
                    extraversion501 + l1_extraversion501 + l2_extraversion501 +
                    agreeableness501 + l1_agreeableness501 + l2_agreeableness501 +
                    emostability501 + l1_emostability501 + l2_emostability501 +
                    lrideol01 + oli201 + occupprestige01 + 
                    age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + l1_morenatthaneu01 + l2_morenatthaneu01,
                  data=subset(Balanced, citizen==1)))


stargazer(M18, M19, M20, M21, type="html",
          covariate.labels = c("Openness", "Lagged Openness (1)", "Lagged Openness (2)",
                               "Conscientiousness", "Lagged Conscientiousness (1)", "Lagged Conscientiousness (2)",
                               "Extraversion", "Lagged Extraversion (1)", "Lagged Extraversion (2)",
                               "Agreeableness", "Lagged Agreeableness (1)", "Lagged Agreeableness (2)",
                               "Emotional Stability", "Lagged Emotional Stability (1)", "Lagged Emotional Stability (2)",
                               "Ideology (L-R)",
                               "Opinion Leadership Index", "Occupational Prestige",
                               "Age","Male","Education", "Urban", "White Ethnicity",
                               "Christian", "Lagged Regional ID (1)", "Lagged Regional ID (2)", 
                               "Lagged National ID (1)", "Lagged National ID (2)",
                               "Lagged European ID (1)", "Lagged European ID (2)",
                               "Lagged Exclusive National ID (1)", "Lagged Exclusive National ID (2)"),
          omit.stat = c("F", "Rsq", "ser"),
          title = "Full Results, Balanced UK Panel (2018, with Double DV/IV Lags)",
          dep.var.labels = c("Regional ID", "National ID", "European ID", "Exclusive National ID"),
          out = "tabs/robustness/ukg-panel-full-balanced-double-lags-on-everything.html")


# * Check for potential imbalance concerns -----

Sub %>%
  mutate(includeinsummary = ifelse(year %in% c(2012, 2015), 1, NA),
         includeinsummary = ifelse(year == 2018 & !is.na(l2_morenatthaneu01), 1, includeinsummary)) %>%
  filter(includeinsummary == 1) -> Check

Check %>%
  group_by(year) %>%
  summarize_at(vars("age", "male","educNEW"), mean, na.rm=TRUE) %>%
  mutate_if(is.numeric, ~round(.,3)) %>%
  rename(Year = year,
         `Average Age` = age,
         `% Male` = male,
         `Mean Education Level` = educNEW) %>%
  mutate(N = c(2002, 1020, 549)) -> tabyeardescript


stargazer(tabyeardescript, type="html",
          out = "tabs/robustness/ukg-panel-year-descriptives.html",
          summary=FALSE) 


# * Let's bootstrap by region -----

Check %>%
  group_by(year) %>%
  nest() %>%
  mutate(fit = map(data, ~lm(regid ~  openness501 + conscientiousness501 + extraversion501 + 
                               agreeableness501 + emostability501 + age01 + male + educNEW01 + rururb01 + eth_white + rel_christian, data= .x)),
         tidy = map(fit, broom::tidy)) %>%
  pull(tidy) %>% 
  map2_df(.,
          c(2012, 2015, 2018),
          ~mutate(.x, year =.y)) -> ymods_regid

Check %>%
  group_by(year) %>%
  nest() %>%
  mutate(fit = map(data, ~lm(natid ~  openness501 + conscientiousness501 + extraversion501 + 
                               agreeableness501 + emostability501 + age01 + male + educNEW01 + rururb01 + eth_white + rel_christian, data= .x)),
         tidy = map(fit, broom::tidy)) %>%
  pull(tidy) %>% 
  map2_df(.,
          c(2012, 2015, 2018),
          ~mutate(.x, year =.y)) -> ymods_natid


Check %>%
  group_by(year) %>%
  nest() %>%
  mutate(fit = map(data, ~lm(europeanid ~  openness501 + conscientiousness501 + extraversion501 + 
                               agreeableness501 + emostability501 + age01 + male + educNEW01 + rururb01 + eth_white + rel_christian, data= .x)),
         tidy = map(fit, broom::tidy)) %>%
  pull(tidy) %>% 
  map2_df(.,
          c(2012, 2015, 2018),
          ~mutate(.x, year =.y)) -> ymods_eurid

Check %>%
  group_by(year) %>%
  nest() %>%
  mutate(fit = map(data, ~lm(morenatthaneu ~  openness501 + conscientiousness501 + extraversion501 + 
                               agreeableness501 + emostability501 + age01 + male + educNEW01 + rururb01 + eth_white + rel_christian, data= .x)),
         tidy = map(fit, broom::tidy)) %>%
  pull(tidy) %>% 
  map2_df(.,
          c(2012, 2015, 2018),
          ~mutate(.x, year =.y)) -> ymods_exclnatid

ukg_regions <- tribble(~region, ~regionname, ~pop,
                       1, "North East", 2657909,
                       2, "North West", 7292093,
                       3, "Yorkshire & Humberside", 5479615,
                       4, "East Midlands", 4804149,
                       5, "West Midlands", 5900757,
                       6, "East of England", 6201214,
                       7, "London", 8908081,
                       8, "South East", 9133625,
                       9, "South West", 5599735,
                       10, "Wales", 3138631,
                       11, "Scotland", 5438100,
                       12, "Northern Ireland", 1881641) %>%
  mutate(totalpop = 66435550) %>%
  mutate(perc = pop/totalpop)


Check %>%
  group_by(year, region) %>%
  tally() %>% na.omit %>%
  left_join(., ukg_regions) %>%
  group_by(year) %>%
  mutate(tot = sum(n),
         perc = n/tot) %>%
  ungroup() %>%
  mutate(regionname = forcats::fct_inorder(regionname)) %>%
  ggplot(.,aes(regionname, perc, fill=as.factor(year))) +
  theme_steve_web() +
  scale_fill_brewer(palette = "OrRd") +
  geom_bar(stat="identity", position="dodge2", color="black") +
  scale_y_continuous(labels = scales::percent) +
  labs(x = "", y = "Percentage of Respondents",
       fill = "")


ggsave("plots/robustness/histogram-regions-ukgp.png", width=15,height=8)




Check %>%
  group_by(year, region) %>%
  tally() %>% na.omit %>%
  left_join(., ukg_regions) %>%
  group_by(year) %>%
  mutate(tot = sum(n),
         perc = n/tot) %>%
  ungroup() %>%
  filter(year == 2012) %>%
  select(region, regionname, perc) -> regionweights







# Total N = 549. That'll be our sample-with-replacement target

boot_regid <- tibble()

jenny() # I got your number...
for (i in 1:1000) {
  Check %>%
    filter(year == 2018) %>%
    left_join(., ukg_regions) %>%
    select(ID:year, regionname, perc, everything()) %>%
    sample_n(549, replace=T, weight=perc) %>%
    do(broom::tidy(lm(regid ~ openness501 + conscientiousness501 + extraversion501 + 
                        agreeableness501 + emostability501 + 
                        age01 + male + educNEW01 + rururb01 + eth_white + rel_christian, data =.))) %>%
    mutate(iter = i) -> hold_this
  
  boot_regid <- bind_rows(boot_regid, hold_this)
  
}

boot_regid %>%
  group_by(term) %>%
  summarize(std.error = sd(estimate),
            upr = quantile(estimate, .975),
            lwr = quantile(estimate, .025),
            estimate = mean(estimate)) %>%
  #mutate(cat = "2018 (Bootstrapped by Region)") %>%
  bind_rows(ymods_regid %>% mutate(upr = estimate + z95*std.error, lwr= estimate - z95*std.error), .) %>%
  mutate(cat = ifelse(!is.na(year), year, "2018 (Bootstrapped by Region)")) %>% filter(term != "(Intercept)") %>%
  filter(year %nin% c(2012, 2015)) %>%
  mutate(term = dplyr::recode(term,
                              "openness501" = "Openness",
                              "conscientiousness501" = "Conscientiousness",
                              "extraversion501" = "Extraversion",
                              "agreeableness501" = "Agreeableness",
                              "emostability501" = "Emotional Stability",
                              "age01" = "Age",
                              "male" = "Male",
                              "educNEW01" = "Education",
                              "rururb01" = "Urban",
                              "eth_white" = "White",
                              "rel_christian" = "Christian")) %>%
  mutate(term = forcats::fct_rev(forcats::fct_inorder(term))) %>%
  ggplot(.,aes(term, estimate, ymin=lwr, ymax = upr)) +
  theme_steve_web() + 
  geom_hline(yintercept = 0, linetype="dashed") +
  facet_wrap(~cat) +
  geom_pointrange() +
  coord_flip() +
  labs(x = "", y = "Coefficient (with 95% Intervals)")


ggsave("plots/robustness/yearmods-regid.png", width=11,height=8)

boot_natid <- tibble()


jenny() # I got your number...
for (i in 1:1000) {
  Check %>%
    filter(year == 2018) %>%
    left_join(., ukg_regions) %>%
    select(ID:year, regionname, perc, everything()) %>%
    sample_n(549, replace=T, weight=perc) %>%
    do(broom::tidy(lm(natid ~ openness501 + conscientiousness501 + extraversion501 + 
                        agreeableness501 + emostability501 + 
                        age01 + male + educNEW01 + rururb01 + eth_white + rel_christian, data =.))) %>%
    mutate(iter = i) -> hold_this
  
  boot_natid <- bind_rows(boot_natid, hold_this)
  
}

boot_natid %>%
  group_by(term) %>%
  summarize(std.error = sd(estimate),
            upr = quantile(estimate, .975),
            lwr = quantile(estimate, .025),
            estimate = mean(estimate)) %>%
  #mutate(cat = "2018 (Bootstrapped by Region)") %>%
  bind_rows(ymods_natid %>% mutate(upr = estimate + z95*std.error, lwr= estimate - z95*std.error), .) %>%
  mutate(cat = ifelse(!is.na(year), year, "2018 (Bootstrapped by Region)")) %>% filter(term != "(Intercept)") %>%
  filter(year %nin% c(2012, 2015)) %>%
  mutate(term = dplyr::recode(term,
                              "openness501" = "Openness",
                              "conscientiousness501" = "Conscientiousness",
                              "extraversion501" = "Extraversion",
                              "agreeableness501" = "Agreeableness",
                              "emostability501" = "Emotional Stability",
                              "age01" = "Age",
                              "male" = "Male",
                              "educNEW01" = "Education",
                              "rururb01" = "Urban",
                              "eth_white" = "White",
                              "rel_christian" = "Christian")) %>%
  mutate(term = forcats::fct_rev(forcats::fct_inorder(term))) %>%
  ggplot(.,aes(term, estimate, ymin=lwr, ymax = upr)) +
  theme_steve_web() + 
  geom_hline(yintercept = 0, linetype="dashed") +
  facet_wrap(~cat) +
  geom_pointrange() +
  coord_flip() +
  labs(x = "", y = "Coefficient (with 95% Intervals)")


ggsave("plots/robustness/yearmods-natid.png", width=11,height=8)



boot_eurid <- tibble()


jenny() # I got your number...
for (i in 1:1000) {
  Check %>%
    filter(year == 2018) %>%
    left_join(., ukg_regions) %>%
    select(ID:year, regionname, perc, everything()) %>%
    sample_n(549, replace=T, weight=perc) %>%
    do(broom::tidy(lm(europeanid ~ openness501 + conscientiousness501 + extraversion501 + 
                        agreeableness501 + emostability501 + 
                        age01 + male + educNEW01 + rururb01 + eth_white + rel_christian, data =.))) %>%
    mutate(iter = i) -> hold_this
  
  boot_eurid <- bind_rows(boot_eurid, hold_this)
  
}

boot_eurid %>%
  group_by(term) %>%
  summarize(std.error = sd(estimate),
            upr = quantile(estimate, .975),
            lwr = quantile(estimate, .025),
            estimate = mean(estimate)) %>%
  #mutate(cat = "2018 (Bootstrapped by Region)") %>%
  bind_rows(ymods_eurid %>% mutate(upr = estimate + z95*std.error, lwr= estimate - z95*std.error), .) %>%
  filter(year %nin% c(2012, 2015)) %>%
  mutate(cat = ifelse(!is.na(year), year, "2018 (Bootstrapped by Region)")) %>% filter(term != "(Intercept)") %>%
  mutate(term = dplyr::recode(term,
                              "openness501" = "Openness",
                              "conscientiousness501" = "Conscientiousness",
                              "extraversion501" = "Extraversion",
                              "agreeableness501" = "Agreeableness",
                              "emostability501" = "Emotional Stability",
                              "age01" = "Age",
                              "male" = "Male",
                              "educNEW01" = "Education",
                              "rururb01" = "Urban",
                              "eth_white" = "White",
                              "rel_christian" = "Christian")) %>%
  mutate(term = forcats::fct_rev(forcats::fct_inorder(term))) %>%
  ggplot(.,aes(term, estimate, ymin=lwr, ymax = upr)) +
  theme_steve_web() + 
  geom_hline(yintercept = 0, linetype="dashed") +
  facet_wrap(~cat) +
  geom_pointrange() +
  coord_flip() +
  labs(x = "", y = "Coefficient (with 95% Intervals)")


ggsave("plots/robustness/yearmods-eurid.png", width=11,height=8)




boot_exclnatid <- tibble()


jenny() # I got your number...
for (i in 1:1000) {
  Check %>%
    filter(year == 2018) %>%
    left_join(., ukg_regions) %>%
    select(ID:year, regionname, perc, everything()) %>%
    sample_n(549, replace=T, weight=perc) %>%
    do(broom::tidy(lm(morenatthaneu ~ openness501 + conscientiousness501 + extraversion501 + 
                        agreeableness501 + emostability501 + 
                        age01 + male + educNEW01 + rururb01 + eth_white + rel_christian, data =.))) %>%
    mutate(iter = i) -> hold_this
  
  boot_exclnatid <- bind_rows(boot_exclnatid, hold_this)
  
}

boot_exclnatid %>%
  group_by(term) %>%
  summarize(std.error = sd(estimate),
            upr = quantile(estimate, .975),
            lwr = quantile(estimate, .025),
            estimate = mean(estimate),) %>%
  #mutate(cat = "2018 (Bootstrapped by Region)") %>%
  bind_rows(ymods_exclnatid %>% mutate(upr = estimate + z95*std.error, lwr= estimate - z95*std.error), .) %>%
  filter(year %nin% c(2012, 2015)) %>%
  mutate(cat = ifelse(!is.na(year), year, "2018 (Bootstrapped by Region)")) %>% filter(term != "(Intercept)") %>%
  mutate(term = dplyr::recode(term,
                              "openness501" = "Openness",
                              "conscientiousness501" = "Conscientiousness",
                              "extraversion501" = "Extraversion",
                              "agreeableness501" = "Agreeableness",
                              "emostability501" = "Emotional Stability",
                              "age01" = "Age",
                              "male" = "Male",
                              "educNEW01" = "Education",
                              "rururb01" = "Urban",
                              "eth_white" = "White",
                              "rel_christian" = "Christian")) %>%
  mutate(term = forcats::fct_rev(forcats::fct_inorder(term))) %>%
  ggplot(.,aes(term, estimate, ymin=lwr, ymax = upr)) +
  theme_steve_web() + 
  geom_hline(yintercept = 0, linetype="dashed") +
  facet_wrap(~cat) +
  geom_pointrange() +
  coord_flip() +
  labs(x = "", y = "Coefficient (with 95% Intervals)")


ggsave("plots/robustness/yearmods-exclnatid.png", width=11,height=8)

# * cluster robust standard errors ------

CSE <- function(mod, cluster) {
  mod %>%
    vcovHC(cluster = cluster) %>% 
    diag() %>% 
    sqrt() %>% 
    as.data.frame() %>% rownames_to_column() %>% as_tibble() %>%
    rename(std.error = 2) %>%
    select(-rowname) %>%
    bind_cols(broom::tidy(mod) %>% select(term, estimate), .) 
}

tidyM5 <- CSE(M5, cluster="group") %>% mutate(cat = "Regional Identification")
tidyM6 <- CSE(M6, cluster="group") %>% mutate(cat = "National Identification")
tidyM7 <- CSE(M7, cluster="group") %>% mutate(cat = "European Identification")
tidyM8 <- CSE(M8, cluster="group") %>% mutate(cat = "Exclusive National Identification")


rbind(tidyM5, tidyM6, tidyM7, tidyM8) %>%
  filter(term != "(Intercept)") %>%
  mutate(term = dplyr::recode(term,
               "openness501" = "Openness",
               "conscientiousness501" = "Conscientiousness",
               "extraversion501" = "Extraversion",
               "agreeableness501" = "Agreeableness",
               "emostability501" = "Emotional Stability",
               "lrideol01" = "Ideology (L-R)",
               "oli201" = "Opinion Leadership Index",
               "occupprestige01" = "Occupational Prestige",
               "age01" = "Age",
               "male" = "Male",
               "educNEW01" = "Education",
               "rururb01" = "Urban",
               "eth_white" = "White",
               "rel_christian" = "Christian",
               "l1_regid01" = "Lagged Value (1)",
               "l1_natid01" = "Lagged Value (1)",
               "l1_europeanid01" = "Lagged Value (1)",
               "l1_morenatthaneu01" = "Lagged Value (1)")) %>%
  mutate(term = forcats::fct_rev(fct_inorder(term)),
         cat = fct_inorder(cat),
         lwr = estimate - z95*std.error,
         upr = estimate + z95*std.error) %>%
  ggplot(.,aes(term, estimate, ymin=lwr, ymax=upr)) +
  theme_steve_web() +
  facet_wrap(~cat, ncol=2) +
  geom_pointrange() +
  geom_hline(yintercept = 0, linetype="dashed") +
  coord_flip() +
  labs(x = "", y = "Coefficient Estimate (with 95% Cluster Robust Standard Errors)")

ggsave("plots/robustness/ukgp-cluster-robust-standard-errors.png", width=11,height=8)


# * Alternative measure of exclusive national identification -----

summary(M22 <- plm(base_excl,
                   data=subset(Balanced, citizen==1), model="random", index=c("ID", "year")))

summary(M23 <- plm(full_excl,
                   data=subset(Balanced, citizen==1), model="random", index=c("ID", "year")))

stargazer(M22, M23, type="html",
          covariate.labels = c("Openness", "Conscientiousness", "Extraversion",
                               "Agreeableness", "Emotional Stability", "Ideology (L-R)", "Opinion Leadership Index",
                               "Occupational Prestige",
                               "Age","Male","Education", "Urban", "White Ethnicity",
                               "Christian", "Lagged Exclusive National ID"),
          omit.stat = c("F", "Rsq"),
          title = "Baseline Results, UK Panel",
          dep.var.labels = c("Kuhn and Nicoli (2020) Measure of Exclusive National Identification"),
          notes = "Panel includes two waves (2015, 2018, with baseline lags from 2012) and 479 unique respondents",
          out = "tabs/robustness/ukg-panel-new-measure-of-exclusive-id.html")


# * Hausman Test

broom::tidy(phtest(M1wi, M1)) %>% mutate(model = "Regional Identification") -> tidyph1
broom::tidy(phtest(M2wi, M2))  %>% mutate(model = "National Identification") -> tidyph2
broom::tidy(phtest(M3wi, M3))  %>% mutate(model = "European Identification")  -> tidyph3
broom::tidy(phtest(M4wi, M4))  %>% mutate(model = "Exclusive National Identification")  -> tidyph4

library(knitr)
library(kableExtra)

rbind(tidyph1, tidyph2, tidyph3, tidyph4) %>%
  select(model, everything(), -method, -alternative, -parameter) %>% data.frame %>%
  kable(., format="html",
        col.names = c("Model", "Chi. Sq. Statistic", "p-Value"),
        align = c("l","c","c"),
        caption = "Hausman Tests of the Baseline UKG Models") %>%
  cat(., file="tabs/robustness/ukg-panel-balanced-hausman-test.html")
