library(tidyverse)
library(stevemisc)
library(stargazer)

CSE <- function(mod) {
  mod %>%
    vcovHC() %>% 
    diag() %>% 
    sqrt() %>% 
    as.data.frame() %>% rownames_to_column() %>% as_tibble() %>%
    rename(std.error = 2) %>%
    select(-rowname) %>%
    bind_cols(broom::tidy(mod) %>% select(term, estimate), .) 
}

# Be mindful of the path here. File name should be "Curtis 2015 Germany Poland UK.dta".
# Also: we recommend (for tidying sake) to keep this file in a separate subdirectory called "data" within
#   your working environment.
# Notice I'm getting just 2015.
Cross <- haven::read_dta("~/Dropbox/EUP R&R with Steve Miller/data/Curtis 2015 Germany Poland UK.dta") %>% filter(year == 2015) %>%
  mutate(countryname = countrycode::countrycode(ccode, "cown", "country.name"))


# Here's how this script is going to work for the outputs. The script will spit stuff out into two directories.
# Tables will be saved as .html files and put into a directory called "tabs"
# Figures/plots will be saved as .png files and put into a directory called "plots".
# Within *both* of those, there will be a separate subdirectory (subsubsdirectory, if you will) for stuff that
#   is there for robustness checks. That directory will be named "robustness".


if (!dir.exists("tabs")){
  dir.create("tabs")
} else {
  print("directory already exists!")
}

if (!dir.exists("tabs/robustness")){
  dir.create("tabs/robustness")
} else {
  print("directory already exists!")
}


if (!dir.exists("plots")){
  dir.create("plots")
} else {
  print("directory already exists!")
}

if (!dir.exists("plots/robustness")){
  dir.create("plots/robustness")
} else {
  print("directory already exists!")
}


# Let's change up the exclusive variable.

Cross %>%
  mutate(morenatthaneu = natid - europeanid,
         exclnatidd = ifelse((natid > europeanid) & (natid>regid), 1, 0),
         exclnatidi = ifelse(europeanid >= regid, natid - europeanid, natid-regid)) -> Cross

# , "hhincyr", "cultid"
Cross %>% haven::zap_labels(.) %>%
  mutate_at(vars("openness5", "conscientiousness5", "extraversion5",
                 "agreeableness5", "emostability5","age",
                 "educNEW","occupprestige", "rururb",
                 "lrideol","countryben",
                 "polint","oli2","pmapprov",
                 "trustEUinsts"), list(`01` = ~scales::rescale(.))) %>%
  rename_at(vars(contains("_01")),
            ~gsub('_', '', .)) -> Cross


Cross %>%
  group_by(countryname, regid) %>%
  tally() %>%
  rename(cat = countryname) %>%
  bind_rows(., Cross %>%
              group_by(regid) %>%
              tally() %>% mutate(cat = "Pooled Sample")) %>%
  group_by(cat) %>%
  mutate(total = sum(n),
         perc = n/total) %>%
  ungroup() %>%
  mutate(cat = forcats::fct_inorder(cat)) %>% 
  ggplot(.,aes(as.factor(regid), perc, fill=cat)) +
  theme_steve_web() +  scale_fill_brewer(palette = "OrRd") +
  geom_bar(stat="identity", position="dodge2", color="black") +
  scale_x_discrete(labels = c("Do Not Identify\nWith It At All", "2", "3",
                              "4", "5","6", "Identify Very Strongly\nWith It")) +
  scale_y_continuous(labels = scales::percent) +
  labs(x = "",
       y = "Percentage of Respondents",
       fill = "",
       title = "Identification with Region")

ggsave("plots/histogram-regid-cross.png")


Cross %>%
  group_by(countryname, natid) %>%
  tally() %>%
  rename(cat = countryname) %>%
  bind_rows(., Cross %>%
              group_by(natid) %>%
              tally() %>% mutate(cat = "Pooled Sample")) %>%
  group_by(cat) %>%
  mutate(total = sum(n),
         perc = n/total) %>%
  ungroup() %>%
  mutate(cat = forcats::fct_inorder(cat)) %>% 
  ggplot(.,aes(as.factor(natid), perc, fill=cat)) +
  theme_steve_web() +  scale_fill_brewer(palette = "OrRd") +
  geom_bar(stat="identity", position="dodge2", color="black") +
  scale_x_discrete(labels = c("Do Not Identify\nWith It At All", "2", "3",
                              "4", "5","6", "Identify Very Strongly\nWith It")) +
  scale_y_continuous(labels = scales::percent) +
  labs(x = "",
       y = "Percentage of Respondents",
       fill = "",
       title = "Identification with Nation")


ggsave("plots/histogram-natid-cross.png")



Cross %>%
  group_by(countryname, europeanid) %>%
  tally() %>%
  rename(cat = countryname) %>%
  bind_rows(., Cross %>%
              group_by(europeanid) %>%
              tally() %>% mutate(cat = "Pooled Sample")) %>%
  group_by(cat) %>%
  mutate(total = sum(n),
         perc = n/total) %>%
  ungroup() %>%
  mutate(cat = forcats::fct_inorder(cat)) %>% 
  ggplot(.,aes(as.factor(europeanid), perc, fill=cat)) +
  theme_steve_web() +  scale_fill_brewer(palette = "OrRd") +
  geom_bar(stat="identity", position="dodge2", color="black") +
  scale_x_discrete(labels = c("Do Not Identify\nWith It At All", "2", "3",
                              "4", "5","6", "Identify Very Strongly\nWith It")) +
  scale_y_continuous(labels = scales::percent) +
  labs(x = "",
       y = "Percentage of Respondents",
       fill = "",
       title = "Identification with Europe")


ggsave("plots/histogram-eurid-cross.png")


Cross %>%
  group_by(countryname, exclnatidi) %>%
  tally() %>%
  rename(cat = countryname) %>%
  bind_rows(., Cross %>%
              group_by(exclnatidi) %>%
              tally() %>% mutate(cat = "Pooled Sample")) %>%
  group_by(cat) %>%
  mutate(total = sum(n),
         perc = n/total) %>%
  ungroup() %>%
  mutate(cat = forcats::fct_inorder(cat)) %>% 
  ggplot(.,aes(as.factor(exclnatidi), perc, fill=cat)) +
  theme_steve_web() +  scale_fill_brewer(palette = "OrRd") +
  geom_bar(stat="identity", position="dodge2", color="black") +
  scale_x_discrete(labels = c("Exclusive\nRegional or European\nIdentification", "-5", "-4", "-3", "-2", "-1",
                              "National\nIdentification\nEqual to\nOther Identification", "1", "2", "3",
                              "4", "5", "Exclusive\nNational Identification")) +
  scale_y_continuous(labels = scales::percent) +
  labs(x = "",
       y = "Percentage of Respondents",
       fill = "",
       title = "Exclusive National Identification")


ggsave("plots/robustness/histogram-exclnatid-cross.png", width=11)


Cross %>%
  group_by(countryname, morenatthaneu) %>%
  tally() %>%
  rename(cat = countryname) %>%
  bind_rows(., Cross %>%
              group_by(morenatthaneu) %>%
              tally() %>% mutate(cat = "Pooled Sample")) %>%
  group_by(cat) %>%
  mutate(total = sum(n),
         perc = n/total) %>%
  ungroup() %>%
  mutate(cat = forcats::fct_inorder(cat)) %>% 
  ggplot(.,aes(as.factor(morenatthaneu), perc, fill=cat)) +
  theme_steve_web() +  scale_fill_brewer(palette = "OrRd") +
  geom_bar(stat="identity", position="dodge2", color="black") +
  scale_x_discrete(labels = c("Exclusive\nEuropean\nIdentification", "-5", "-4", "-3", "-2", "-1",
                              "National\nIdentification\nEqual to\nOther Identification", "1", "2", "3",
                              "4", "5", "Exclusive\nNational Identification")) +
  scale_y_continuous(labels = scales::percent) +
  labs(x = "",
       y = "Percentage of Respondents",
       fill = "",
       title = "Exclusive National Identification")


ggsave("plots/histogram-morenatthaneu-cross.png", width=11)

# Amber wants a particular layout of variables and it'd probably just be easier to do it this way.
base_reg <- as.formula("regid ~ openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + 
                       age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + (1 | countryname)")

base_nat <- as.formula("natid ~  openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + 
                       age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + (1 | countryname)")

base_eur <- as.formula("europeanid ~   openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + 
                       age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + (1 | countryname)")

base_excl <- as.formula("exclnatidi ~ openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + 
                        age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + (1 | countryname)")

base_excl_orig <- as.formula("morenatthaneu ~ openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + 
                        age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + (1 | countryname)")

full_reg <- as.formula("regid ~ openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + lrideol01 + oli201 + occupprestige01 + 
                       age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + (1 | countryname)")

full_nat <- as.formula("natid ~  openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + lrideol01 + oli201 + occupprestige01 + 
                       age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + (1 | countryname)")

full_eur <- as.formula("europeanid ~   openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + lrideol01 + oli201 + occupprestige01 + 
                       age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + (1 | countryname)")

full_excl <- as.formula("exclnatidi ~ openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + lrideol01 + oli201 + occupprestige01 + 
                        age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + (1 | countryname)")

full_excl_orig <- as.formula("morenatthaneu ~ openness501 + conscientiousness501 + extraversion501 + 
                    agreeableness501 + emostability501 + lrideol01 + oli201 + occupprestige01 + 
                        age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + (1 | countryname)")



library(lme4)
M1 <- lmer(base_reg, data=Cross)
M2 <- lmer(base_nat, data=Cross)
M3 <- lmer(base_eur, data=Cross)
M4 <- lmer(base_excl, data=Cross)

get_sd <- function(mod, raneflev) {
  VarCorr(mod) %>% tbl_df() %>%
    filter(grp == raneflev) %>%
    select(sdcor) %>%
    pull() -> x
    round(x, 3)
}


tribble(~stat, ~M1, ~M2, ~M3, ~M4,
        "Number of Countries", 3, 3, 3, 3,
        "sd(Country)", get_sd(M1, "countryname"), get_sd(M2, "countryname"), get_sd(M3, "countryname"), get_sd(M4, "countryname"),
        "", NA, NA, NA, NA,
        "N", nobs(M1), nobs(M2), nobs(M3), nobs(M4)) -> mod_stats


stargazer(M1, M2, M3, M4,  type="html",
          out = "tabs/cross2015-baseline.html",
          title = "Baseline Results, Pooled 2015 Sample",
          dep.var.labels = c("Regional ID", "National ID", "European ID", "Exclusive National ID"),
          omit.stat = c("ll","aic","bic"),
          notes = "Random effects omitted for presentation.",
          covariate.labels = c("Openness", "Conscientiousness", "Extraversion",
                               "Agreeableness", "Emotional Stability",
                               "Age","Male","Education", "Urban", "White Ethnicity",
                               "Christian"))


M5 <- lmer(full_reg, data=Cross)
M6 <- lmer(full_nat, data=Cross)
M7 <- lmer(full_eur, data=Cross)
M8 <- lmer(full_excl, data=Cross)


stargazer(M5, M6, M7, M8,  type="html",
          out = "tabs/cross2015-full.html",
          title = "Full Results, Pooled 2015 Sample",
          dep.var.labels = c("Regional ID", "National ID", "European ID", "Exclusive National ID"),
          omit.stat = c("ll","aic","bic"),
          notes = "Random effects omitted for presentation.",
          covariate.labels = c("Openness", "Conscientiousness", "Extraversion",
                               "Agreeableness", "Emotional Stability", "Ideology (L-R)",
                               "Opinion Leadership Index", "Occupational Prestige",
                               "Age","Male","Education", "Urban", "White Ethnicity",
                               "Christian"))


M9 <- lm(regid ~ openness501 + conscientiousness501 + extraversion501 + 
           agreeableness501 + emostability501 + lrideol01 + oli201 + occupprestige01 + 
           age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + factor(countryname),
         data= Cross)


M10 <- lm(natid ~ openness501 + conscientiousness501 + extraversion501 + 
           agreeableness501 + emostability501 + lrideol01 + oli201 + occupprestige01 + 
           age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + factor(countryname),
         data= Cross)


M11 <- lm(europeanid ~ openness501 + conscientiousness501 + extraversion501 + 
           agreeableness501 + emostability501 + lrideol01 + oli201 + occupprestige01 + 
           age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + factor(countryname),
         data= Cross)


M12 <- lm(morenatthaneu ~ openness501 + conscientiousness501 + extraversion501 + 
           agreeableness501 + emostability501 + lrideol01 + oli201 + occupprestige01 + 
           age01 + male + educNEW01 + rururb01 + eth_white + rel_christian + factor(countryname),
         data= Cross)


stargazer(M9, M10, M11, M12,  type="html",
          out = "tabs/robustness/cross2015-full-fixed-effects.html",
          title = "Full Results, Pooled 2015 Sample",
          dep.var.labels = c("Regional ID", "National ID", "European ID", "Exclusive National ID"),
          omit.stat = c("ll","aic","bic", "f","ser","rsq"),
          notes = "Germany is baseline group for country fixed effects.",
          covariate.labels = c("Openness", "Conscientiousness", "Extraversion",
                               "Agreeableness", "Emotional Stability", "Ideology (L-R)",
                               "Opinion Leadership Index", "Occupational Prestige",
                               "Age","Male","Education", "Urban", "White Ethnicity",
                               "Christian", "Country = Poland", "Country = United Kingdom"))


M13 <- lmer(base_excl, data=Cross)
M14 <- lmer(full_excl, data=Cross)


stargazer(M13, M14, type="html",
          covariate.labels = c("Openness", "Conscientiousness", "Extraversion",
                               "Agreeableness", "Emotional Stability", "Ideology (L-R)", "Opinion Leadership Index",
                               "Occupational Prestige",
                               "Age","Male","Education", "Urban", "White Ethnicity",
                               "Christian"),
          omit.stat = c("F", "Rsq", "ll", "aic", "bic"),
          title = "Baseline Results, UK Panel",
          dep.var.labels = c("Kuhn and Nicoli (2020) Measure of Exclusive National Identification"),
          notes = "Random effects omitted for presentation.",
          out = "tabs/robustness/cross2015-new-measure-of-exclusive-id.html")

